#!/bin/sh
#   Copyright (c) 2011 digitalSTROM.org, Zurich, Switzerland
#
#   Author: Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
#
#   This file is part of digitalSTROM Server.
#
#   netinfo.sh is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   netinfo.sh is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this file. If not, see <http://www.gnu.org/licenses/>.

# source common functions
. ./errlib.sh
. ./jsonlib.sh
. ./util.sh

LOCATION_DIRECTORY="/usr/share/dss/data/config.d"
LOCATION_CONFIG="location.xml"
LOCATION="$LOCATION_DIRECTORY/$LOCATION_CONFIG"
echo "Content-Type: application/json"
echo ""

COUNTRY=
LOC=
LATITUDE=
LONGITUDE=
GMTOFFSET=
TIMEZONE=

# Parameters: COUNTRY, LOCATION, LATITUDE, LONGITUDE, GMTOFFSET, [ TIMEZONE ]

if [[ ! -f "$LOCATION" ]]; then
    json_error $ERR_UNAVAILABLE "Geolocation configuration does not exist"
    exit 1
fi

if [[ ! -x $XMLLINT ]]; then
    json_error $ERR_DOWAIT "xmllint tool not found"
    exit 1
fi

COUNTRY=`$XMLLINT --xpath "/properties/property/*[@name='geodata/country']/value/text()" $LOCATION 2>/dev/null`
if [[ "$?" -ne "$ERR_OK" ]]; then
    json_error $ERR_INVALID "Country information not found"
    exit 1
fi

if [[ "$COUNTRY" == "other" ]]; then
    COUNTRY="-"
fi

if [[ "$COUNTRY" != "-" ]]; then
    LOC=`$XMLLINT --xpath "/properties/property/*[@name='geodata/location']/value/text()" $LOCATION 2>/dev/null`
    if [[ "$?" -ne "$ERR_OK" ]]; then
        json_error $ERR_INVALID "Location information not found"
        exit 1
    fi
fi

LATITUDE=`$XMLLINT --xpath "/properties/property/*[@name='geodata/latitude']/value/text()" $LOCATION 2>/dev/null`
if [[ "$?" -ne "$ERR_OK" ]]; then
    json_error $ERR_INVALID "Latitude information not found"
    exit 1
fi

LONGITUDE=`$XMLLINT --xpath "/properties/property/*[@name='geodata/longitude']/value/text()" $LOCATION 2>/dev/null`
if [[ "$?" -ne "$ERR_OK" ]]; then
    json_error $ERR_INVALID "Longitude information not found"
    exit 1
fi

GMTOFFSET=`$XMLLINT --xpath "/properties/property/*[@name='geodata/offsetGMT']/value/text()" $LOCATION 2>/dev/null`
if [[ "$?" -ne "$ERR_OK" ]]; then
    json_error $ERR_INVALID "GMT offset information not found"
    exit 1
fi

echo -n "{ \"success\": true, \"code\": $ERR_OK, \"message\": \"OK\", "
echo -n "\"data\": { \"country\": \"$COUNTRY\", \"location\": \"$LOC\", "
echo -n "\"latitude\": $LATITUDE, \"longitude\": $LONGITUDE, "
echo -n "\"gmtoffset\": $GMTOFFSET"
echo " } }"
